@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.56 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,6 +36,8 @@
 #include "pagedef.h"
 #include "debug.h"
 #include "dirdef.h"
+#include "vhdldocgen.h"
+#include "layout.h"
 
 // #define GROUP_COLOR "#ff8080"
 
@@ -381,7 +383,7 @@ static const char tabs_css[] =
 "   float            : left;\n"
 "   background       : url(\"tab_r.gif\") no-repeat right top;\n"
 "   border-bottom    : 1px solid #84B0C7;\n"
-"   font-size        : x-small;\n"
+"   font-size        : 8px;\n"
 "   font-weight      : bold;\n"
 "   text-decoration  : none;\n"
 "}\n"
@@ -415,7 +417,7 @@ static const char tabs_css[] =
 "\n"
 "DIV.tabs TD\n"
 "{\n"
-"   font-size        : x-small;\n"
+"   font-size        : 8px;\n"
 "   font-weight      : bold;\n"
 "   text-decoration  : none;\n"
 "}\n"
@@ -443,7 +445,7 @@ static const char tabs_css[] =
 "   padding-bottom   : 6px;\n"
 "}\n"
 "\n"
-"DIV.nav\n"
+"DIV.navpath\n"
 "{\n"
 "   background       : none;\n"
 "   border           : none;\n"
@@ -600,9 +602,7 @@ static void writeDefaultHeaderFile(QTextStream &t, const char *title,
 void HtmlGenerator::writeHeaderFile(QFile &file)
 {
   QTextStream t(&file);
-#if QT_VERSION >= 200
-  t.setEncoding(QTextStream::Latin1);
-#endif
+  t.setEncoding(QTextStream::UnicodeUTF8);
   writeDefaultHeaderFile(t,"$title",relativePathToRoot(0),TRUE);
 }
 
@@ -806,11 +806,11 @@ void HtmlGenerator::startDoxyAnchor(const char *,const char *,
 {
   t << "<a class=\"anchor\" name=\"" << anchor << "\"></a>";
   t << "<!-- doxytag: member=\"";
-  docify(name); 
+  docify(name,TRUE); 
   t << "\" ref=\""; 
-  docify(anchor); 
+  docify(anchor,TRUE); 
   t << "\" args=\"";
-  docify(args);
+  docify(args,TRUE);
   t << "\" -->";
 }
 
@@ -840,7 +840,7 @@ void HtmlGenerator::writeString(const char *text)
 
 void HtmlGenerator::startIndexItem(const char *ref,const char *f)
 {
-  //printf("HtmlGenerator::startIndexItem(%s,%s,%s)\n",ref,f,name);
+  //printf("HtmlGenerator::startIndexItem(%s,%s)\n",ref,f);
   QCString *dest;
   t << "<li>";
   if (ref || f)
@@ -979,7 +979,7 @@ void HtmlGenerator::endTextLink()
 void HtmlGenerator::startHtmlLink(const char *url)
 {
   t << "<a ";
-  if (Config_getBool("GENERATE_TREEVIEW")) t << "target=\"top\" ";
+  if (usingTreeIndex()) t << "target=\"top\" ";
   t << "href=\"";
   if (url) t << url;
   t << "\">"; 
@@ -1029,6 +1029,11 @@ void HtmlGenerator::endSection(const char *,SectionInfo::SectionType type)
 }
 
 void HtmlGenerator::docify(const char *str)
+{
+  docify(str,FALSE);
+}
+
+void HtmlGenerator::docify(const char *str,bool inHtmlComment)
 {
   if (str)
   {
@@ -1043,6 +1048,7 @@ void HtmlGenerator::docify(const char *str)
         case '>':  t << "&gt;"; break;
         case '&':  t << "&amp;"; break;
         case '"':  t << "&quot;"; break;
+        case '-':  if (inHtmlComment) t << "&#45;"; else t << "-"; break;
         case '\\':
                    if (*p=='<')
                      { t << "&lt;"; p++; }
@@ -1445,7 +1451,7 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
       t << "          <td>";
       if (closeBracket) t << "&nbsp;)";
       t << "&nbsp;</td>" << endl;
-      t << "          <td width=\"100%\">";
+      t << "          <td>";
     }
     else
     {
@@ -1456,7 +1462,7 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
       t << "          <td>";
       if (closeBracket) t << ")";
       t << "</td>" << endl;
-      t << "          <td></td><td></td><td width=\"100%\">";
+      t << "          <td></td><td></td><td>";
     }
   }
   else
@@ -1619,17 +1625,17 @@ void HtmlGenerator::writeNonBreakableSpace(int n)
   }
 }
 
-void HtmlGenerator::writeLineNumber(const char *ref,const char *file,
+void HtmlGenerator::writeLineNumber(const char *ref,const char *filename,
                                     const char *anchor,int l)
 {
   QCString lineNumber,lineAnchor;
   lineNumber.sprintf("%05d",l);
   lineAnchor.sprintf("l%05d",l);
 
-  if (file)
+  if (filename)
   {
     startCodeAnchor(lineAnchor);
-    writeCodeLink(ref,file,anchor,lineNumber,0);
+    writeCodeLink(ref,filename,anchor,lineNumber,0);
     endCodeAnchor();
   }
   else
@@ -1642,13 +1648,13 @@ void HtmlGenerator::writeLineNumber(const char *ref,const char *file,
 }
 
 void HtmlGenerator::startSimpleSect(SectionTypes,
-                                const char *file,const char *anchor,
+                                const char *filename,const char *anchor,
                                 const char *title)
 {
   t << "<dl compact><dt><b>";
-  if (file)
+  if (filename)
   {
-    writeObjectLink(0,file,anchor,title);
+    writeObjectLink(0,filename,anchor,title);
   }
   else
   {
@@ -1688,8 +1694,8 @@ static void startQuickIndexList(QTextStream &t,bool compact)
 {
   if (compact) 
   {
-    t << "<div class=\"tabs\">\n";
-    t << "  <ul>\n"; 
+    t << "  <div class=\"tabs\">\n";
+    t << "    <ul>\n"; 
   }
   else 
   {
@@ -1701,8 +1707,8 @@ static void endQuickIndexList(QTextStream &t,bool compact)
 {
   if (compact) 
   {
-    t << "  </ul>\n";
-    t << "</div>\n";
+    t << "    </ul>\n";
+    t << "  </div>\n";
   }
   else 
   {
@@ -1714,7 +1720,7 @@ static void startQuickIndexItem(QTextStream &t,const char *l,
                                 bool hl,bool /*compact*/,
                                 const QCString &relPath)
 {
-  t << "    <li"; if (hl) t << " class=\"current\"";
+  t << "      <li"; if (hl) t << " class=\"current\"";
   t << "><a ";
   t << "href=\"" << relPath << l << "\">";
   t << "<span>";
@@ -1732,10 +1738,183 @@ static QCString fixSpaces(const QCString &s)
   return substitute(s," ","&nbsp;");
 }
 
+#define NEW_LAYOUT
+#ifdef NEW_LAYOUT
+
+static bool quickLinkVisible(LayoutNavEntry::Kind kind)
+{
+  switch (kind)
+  {
+    case LayoutNavEntry::MainPage:         return TRUE; 
+    case LayoutNavEntry::Pages:            return indexedPages>0;
+    case LayoutNavEntry::Modules:          return documentedGroups>0;
+    case LayoutNavEntry::Namespaces:       return documentedNamespaces>0;
+    case LayoutNavEntry::NamespaceMembers: return documentedNamespaceMembers[NMHL_All]>0;
+    case LayoutNavEntry::Classes:          return annotatedClasses>0;
+    case LayoutNavEntry::ClassAnnotated:   return annotatedClasses>0; 
+    case LayoutNavEntry::ClassHierarchy:   return hierarchyClasses>0;
+    case LayoutNavEntry::ClassMembers:     return documentedClassMembers[CMHL_All]>0;
+    case LayoutNavEntry::Files:            return documentedHtmlFiles>0;
+    case LayoutNavEntry::FileGlobals:      return documentedFileMembers[FMHL_All]>0;
+    case LayoutNavEntry::Dirs:             return documentedDirs>0;
+    case LayoutNavEntry::Examples:         return Doxygen::exampleSDict->count()>0;
+  }
+  return FALSE;
+}
+
+static void renderQuickLinksAsTree(QTextStream &t,const QCString &relPath,LayoutNavEntry *root)
+
+{
+  QListIterator<LayoutNavEntry> li(root->children());
+  LayoutNavEntry *entry;
+  int count=0;
+  for (li.toFirst();(entry=li.current());++li)
+  {
+    if (entry->visible() && quickLinkVisible(entry->kind())) count++;
+  }
+  if (count>0) // at least one item is visible
+  {
+    startQuickIndexList(t,FALSE);
+    for (li.toFirst();(entry=li.current());++li)
+    {
+      if (entry->visible() && quickLinkVisible(entry->kind()))
+      {
+        startQuickIndexItem(t,entry->baseFile()+Doxygen::htmlFileExtension,
+                            FALSE,FALSE,relPath);
+        t << fixSpaces(entry->title());
+        endQuickIndexItem(t);
+        // recursive into child list
+        renderQuickLinksAsTree(t,relPath,entry);
+      }
+    }
+    endQuickIndexList(t,FALSE);
+  }
+}
+
+
+static void renderQuickLinksAsTabs(QTextStream &t,const QCString &relPath,
+                             LayoutNavEntry *hlEntry,LayoutNavEntry::Kind kind,
+                             bool highlightParent,bool highlightSearch)
+{
+  if (hlEntry->parent()) // first draw the tabs for the parent of hlEntry
+  {
+    renderQuickLinksAsTabs(t,relPath,hlEntry->parent(),kind,highlightParent,highlightSearch);
+  }
+  if (hlEntry->parent() && hlEntry->parent()->children().count()>0) // draw tabs for row containing hlEntry
+  {
+    QListIterator<LayoutNavEntry> li(hlEntry->parent()->children());
+    LayoutNavEntry *entry;
+
+    int count=0;
+    for (li.toFirst();(entry=li.current());++li)
+    {
+      if (entry->visible() && quickLinkVisible(entry->kind())) count++;
+    }
+    if (count>0) // at least one item is visible
+    {
+      startQuickIndexList(t,TRUE);
+      for (li.toFirst();(entry=li.current());++li)
+      {
+        if (entry->visible() && quickLinkVisible(entry->kind()))
+        {
+          startQuickIndexItem(t,entry->baseFile()+Doxygen::htmlFileExtension,
+              entry==hlEntry  && (entry->children().count()>0 || (entry->kind()==kind && !highlightParent)),
+              TRUE,relPath);
+          t << fixSpaces(entry->title());
+          endQuickIndexItem(t);
+        }
+      }
+      if (hlEntry->parent()==LayoutDocManager::instance().rootNavEntry())
+      {
+        // last item of the top row -> special case for search engine
+        if (Config_getBool("SEARCHENGINE"))
+        {
+          QCString searchFor = fixSpaces(theTranslator->trSearchForIndex());
+          if (searchFor.at(0)=='S') searchFor="<u>S</u>"+searchFor.mid(1);
+          t << "    <li>\n";
+          t << "      <form action=\"" << relPath << "search.php\" method=\"get\">\n";
+          t << "        <table cellspacing=\"0\" cellpadding=\"0\" border=\"0\">\n";
+          t << "          <tr>\n";
+          t << "            <td><label>&nbsp;" << searchFor << "&nbsp;</label></td>\n";
+          if (!highlightSearch)
+          {
+            t << "            <td><input type=\"text\" name=\"query\" value=\"\" size=\"20\" accesskey=\"s\"/></td>\n";
+            t << "          </tr>\n";
+            t << "        </table>\n";
+            t << "      </form>\n";
+            t << "    </li>\n";
+          }
+        } 
+        if (!highlightSearch) // on the search page the page will be ended by the
+                              // page itself
+        {
+          endQuickIndexList(t,TRUE);
+        }
+      }
+      else // normal case
+      {
+        endQuickIndexList(t,TRUE);
+      }
+    }
+  }
+}
+
+static void writeDefaultQuickLinks(QTextStream &t,bool compact,
+                                   HighlightedItem hli,const QCString &relPath)
+{
+  LayoutNavEntry *root = LayoutDocManager::instance().rootNavEntry();
+  LayoutNavEntry::Kind kind = (LayoutNavEntry::Kind)-1;
+  bool highlightParent=FALSE;
+  switch (hli) // map HLI enums to LayoutNavEntry::Kind enums
+  {
+    case HLI_Main:             kind = LayoutNavEntry::MainPage;         break;
+    case HLI_Modules:          kind = LayoutNavEntry::Modules;          break;
+    case HLI_Directories:      kind = LayoutNavEntry::Dirs;             break;
+    case HLI_Namespaces:       kind = LayoutNavEntry::Namespaces;       break;
+    case HLI_Hierarchy:        kind = LayoutNavEntry::ClassHierarchy;   break;
+    case HLI_Classes:          kind = LayoutNavEntry::Classes;          break;
+    case HLI_Annotated:        kind = LayoutNavEntry::ClassAnnotated;   break;
+    case HLI_Files:            kind = LayoutNavEntry::Files;            break;
+    case HLI_NamespaceMembers: kind = LayoutNavEntry::NamespaceMembers; break;
+    case HLI_Functions:        kind = LayoutNavEntry::ClassMembers;     break;
+    case HLI_Globals:          kind = LayoutNavEntry::FileGlobals;      break;
+    case HLI_Pages:            kind = LayoutNavEntry::Pages;            break;
+    case HLI_Examples:         kind = LayoutNavEntry::Examples;         break;
+    case HLI_ClassVisible:     kind = LayoutNavEntry::Classes;    highlightParent = TRUE; break;
+    case HLI_NamespaceVisible: kind = LayoutNavEntry::Namespaces; highlightParent = TRUE; break;
+    case HLI_FileVisible:      kind = LayoutNavEntry::Files;      highlightParent = TRUE; break;
+    case HLI_None:   break;
+    case HLI_Search: break;
+  }
+  
+  if (compact)
+  {
+    // find highlighted index item
+    LayoutNavEntry *hlEntry = root->find(kind);
+    if (!hlEntry) // highlighted item not found in the index! -> just show the level 1 index...
+    {
+      highlightParent=TRUE;
+      hlEntry = root->children().getFirst();
+      if (hlEntry==0) 
+      {
+        return; // argl, empty index!
+      }
+    }
+    renderQuickLinksAsTabs(t,relPath,hlEntry,kind,highlightParent,hli==HLI_Search);
+  }
+  else
+  {
+    renderQuickLinksAsTree(t,relPath,root);
+  }
+}
+
+#else // old fixed layout
+
 static void writeNamespaceSubIndex(QTextStream &t,bool compact,
                                   HighlightedItem hli,const QCString &relPath
                                  )
 {
+  bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
   startQuickIndexList(t,compact);
   if (documentedNamespaces>0)
   {
@@ -1745,7 +1924,11 @@ static void writeNamespaceSubIndex(QTextStream &t,bool compact,
     {
       t << fixSpaces(theTranslator->trPackages());
     }
-    else
+    else if(fortranOpt)
+    {
+      t << theTranslator->trModulesList();
+    }
+      else
     {
       t << theTranslator->trNamespaceList();
     }
@@ -1759,7 +1942,11 @@ static void writeNamespaceSubIndex(QTextStream &t,bool compact,
     {
       t << fixSpaces(theTranslator->trPackageMembers());
     }
-    else
+    else if(fortranOpt)
+    {
+      t << fixSpaces(theTranslator->trModulesMembers());
+    }
+      else
     {
       t << fixSpaces(theTranslator->trNamespaceMembers());
     }
@@ -1772,6 +1959,8 @@ static void writeClassSubIndex(QTextStream &t,bool compact,
                                HighlightedItem hli,const QCString &relPath
                               )
 {
+  bool fortranOpt=Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  bool vhdlOpt=Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   startQuickIndexList(t,compact);
   if (annotatedClasses>0)
   {
@@ -1784,21 +1973,46 @@ static void writeClassSubIndex(QTextStream &t,bool compact,
     }
     startQuickIndexItem(t,"annotated"+Doxygen::htmlFileExtension,
         hli==HLI_Annotated,compact,relPath);
-    t << fixSpaces(theTranslator->trCompoundList());
+      if (fortranOpt)
+      {
+        t << fixSpaces(theTranslator->trCompoundListFortran());
+      }
+      else if (vhdlOpt)
+      {
+        t << fixSpaces(VhdlDocGen::trDesignUnitList());
+      }
+      else
+      {
+        t << fixSpaces(theTranslator->trCompoundList());
+      }
+    
     endQuickIndexItem(t);
   } 
   if (hierarchyClasses>0)
   {
+    QCString title = theTranslator->trClassHierarchy();
+    if (vhdlOpt) title = VhdlDocGen::trDesignUnitHierarchy();
     startQuickIndexItem(t,"hierarchy"+Doxygen::htmlFileExtension,
         hli==HLI_Hierarchy,compact,relPath);
-    t << fixSpaces(theTranslator->trClassHierarchy());
+    t << fixSpaces(title);
     endQuickIndexItem(t);
   } 
   if (documentedClassMembers[CMHL_All]>0)
   {
     startQuickIndexItem(t,"functions"+Doxygen::htmlFileExtension,
         hli==HLI_Functions,compact,relPath);
-    t << fixSpaces(theTranslator->trCompoundMembers());
+    if (fortranOpt)
+    {
+      t << fixSpaces(theTranslator->trCompoundMembersFortran());
+    }
+    else if (vhdlOpt)
+    {
+      t << fixSpaces(VhdlDocGen::trDesignUnitMembers());
+    }
+    else
+    {
+      t << fixSpaces(theTranslator->trCompoundMembers());
+    }
     endQuickIndexItem(t);
   } 
   endQuickIndexList(t,compact);
@@ -1828,9 +2042,11 @@ static void writeFileSubIndex(QTextStream &t,bool compact,
 static void writeDefaultQuickLinks(QTextStream &t,bool compact,
                                    HighlightedItem hli,const QCString &relPath)
 {
+  bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  bool vhdlOpt    = Config_getBool("OPTIMIZE_OUTPUT_VHDL");
   startQuickIndexList(t,compact);
 
-  if (Config_getBool("GENERATE_TREEVIEW"))
+  if (usingTreeIndex())
   {
     startQuickIndexItem(t,"main"+Doxygen::htmlFileExtension,
                         hli==HLI_Main,compact,relPath);
@@ -1843,6 +2059,18 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
   t << fixSpaces(theTranslator->trMainPage());
   endQuickIndexItem(t);
 
+  // -------------- Related pages
+  
+  if (indexedPages>0)
+  {
+    startQuickIndexItem(t,"pages"+Doxygen::htmlFileExtension,
+                        hli==HLI_Pages,compact,relPath);
+    t << fixSpaces(theTranslator->trRelatedPages());
+    endQuickIndexItem(t);
+  } 
+
+  // --------------- Modules
+
   if (documentedGroups>0)
   {
     startQuickIndexItem(t,"modules"+Doxygen::htmlFileExtension,
@@ -1862,6 +2090,10 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
     {
       t << fixSpaces(theTranslator->trPackages());
     }
+    else if (fortranOpt)
+    {
+      t << theTranslator->trModules();
+    }
     else
     {
       t << theTranslator->trNamespaces();
@@ -1885,7 +2117,18 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
           hli==HLI_Annotated || hli==HLI_Functions || hli==HLI_ClassVisible,
           compact,relPath);
     }
-    t << fixSpaces(theTranslator->trClasses());
+    if (fortranOpt)
+    {
+      t << fixSpaces(theTranslator->trDataTypes());
+    }
+    else if (vhdlOpt)
+    {
+      t << fixSpaces(VhdlDocGen::trDesignUnits());
+    }
+    else
+    {
+      t << fixSpaces(theTranslator->trClasses());
+    }
     endQuickIndexItem(t);
     if (!compact)
     {
@@ -1893,7 +2136,6 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
     }
   }
 
-
   // -------------- File
 
   if (documentedHtmlFiles>0)
@@ -1919,16 +2161,6 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
     endQuickIndexItem(t);
   } 
 
-  // -------------- Related pages
-  
-  if (indexedPages>0)
-  {
-    startQuickIndexItem(t,"pages"+Doxygen::htmlFileExtension,
-                        hli==HLI_Pages,compact,relPath);
-    t << fixSpaces(theTranslator->trRelatedPages());
-    endQuickIndexItem(t);
-  } 
-
   // -------------- Examples
   
   if (Doxygen::exampleSDict->count()>0)
@@ -1993,6 +2225,33 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
   }
   
 }
+#endif
+
+void HtmlGenerator::startQuickIndices()
+{
+  if (!Config_getBool("DISABLE_INDEX"))
+  {
+    t << "<div class=\"navigation\" id=\"top\">" << endl;
+  }
+}
+
+void HtmlGenerator::endQuickIndices()
+{
+  if (!Config_getBool("DISABLE_INDEX"))
+  {
+    t << "</div>" << endl;
+  }
+}
+
+void HtmlGenerator::startContents()
+{
+  t << "<div class=\"contents\">" << endl;
+}
+
+void HtmlGenerator::endContents()
+{
+  t << "</div>" << endl;
+}
 
 void HtmlGenerator::writeQuickLinks(bool compact,HighlightedItem hli)
 {
@@ -2008,9 +2267,7 @@ void HtmlGenerator::writeSearchPage()
     if (f.open(IO_WriteOnly))
     {
       QTextStream t(&f);
-#if QT_VERSION >= 200
-      t.setEncoding(QTextStream::Latin1);
-#endif
+      t.setEncoding(QTextStream::UnicodeUTF8);
       if (g_header.isEmpty()) 
       {
         writeDefaultHeaderFile(t,theTranslator->trSearch().data(),0,FALSE);
@@ -2143,4 +2400,15 @@ void HtmlGenerator::endConstraintList()
   t << "</div>" << endl;
 }
 
+void HtmlGenerator::lineBreak(const char *style)
+{
+  if (style)
+  {
+    t << "<br class=\"" << style << "\">" << endl;
+  }
+  else
+  {
+    t << "<br>" << endl;
+  }
+}
 
