@@ -2,7 +2,7 @@
  *
  * $Id: translator_ro.h,v 1.3 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2008 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,44 +16,48 @@
  */
 
 /* The translation from English to Romanian by Alexandru Iosup [aiosup@yahoo.com].
+ * Updated by Ionut Dumitrascu [reddumy@yahoo.com]
  *
  * Disclaimer: I hope I translated these to Romanian keeping
- * the meaning of the sentences intact. Keep in mind that I used C-words were possible,
- * (e.g. the romanian for typedef is much unexpressive than the original), since we are
- * producing C-documentation of our projects.
+ * the meaning of the sentences intact. I used C-words were possible,
+ * (e.g. the Romanian "definire de tip" for "typedef" is too long and 
+ * unexpressive).
  *
  * If you have suggestions, please mail the comments and text proposals to the address 
  * shown aprox.10 lines above
  * 
  * -------------------------------------------
  * Project start                : 20.Sep.2k
- * Last Doxygen version covered : 1.2.14
- * Last revision                : 07.Mar.2k2
+ * Last Doxygen version covered : 1.4.1
+ * Last revision                : 01.Mar.2k5
  * -------------------------------------------
  *
  * Revision history
  * ----------------
- * 20.Sep.2k   First version, covering Doxygen 1.2.1
+ * 28.07.2008 - Updated version - covering Doxygen 1.5.6 - and some minor changes
+ * 01.Mar.2k5  Third revision, covering Doxygen 1.4.1
  *
  * 07.Mar.2k2  Second revision, covering Doxygen 1.2.14
  *             - fixed some bugs
+ *
+ * 20.Sep.2k   First version, covering Doxygen 1.2.1
+ *
  */
 #ifndef TRANSLATOR_RO_H
 #define TRANSLATOR_RO_H
 
 
-class TranslatorRomanian: public TranslatorAdapter_1_2_16
+class TranslatorRomanian : public TranslatorAdapter_1_4_1
 {
   public:
 
     // --- Language control methods -------------------
     
-    /*! Used for identification of the language. May resemble 
-     * the string returned by latexBabelPackage(), but it is not used
-     * for the same purpose. The identification should not be translated.
-     * It should be replaced by the name of the language in English
-     * (e.g. Czech, Japanese, Russian, etc.). It should be equal to 
-     * the identification in language.h.
+    /*! Used for identification of the language. The identification 
+     * should not be translated. It should be replaced by the name 
+     * of the language in English using lower-case characters only
+     * (e.g. "czech", "japanese", "russian", etc.). It should be equal to 
+     * the identification used in language.cpp.
      */
     virtual QCString idLanguage()
     { return "romanian"; }
@@ -73,7 +77,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "\\usepackage{romanian}\n";
+      return "\\usepackage[romanian]{babel}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -136,7 +140,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
 
     /*! this is the first part of a sentence that is followed by a class name */
     virtual QCString trThisIsTheListOfAllMembers()
-    { return "Aceasta este lista complet a membrilor din "; }
+    { return "Lista complet a membrilor din "; }
 
     /*! this is the remainder of the sentence after the class name */
     virtual QCString trIncludingInheritedMembers()
@@ -247,7 +251,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! This is an introduction to the list with all files. */
     virtual QCString trFileListDescription(bool extractAll)
     {
-      QCString result="Aceasta este lista tuturor ";
+      QCString result="Lista tuturor ";
       result+="fiierelor";
 	  if (!extractAll) result+=" documentate";
 	  result+=", cu scurte descrieri:";
@@ -259,11 +263,11 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Acestea sunt structurile de date, cu scurte descrieri:"; 
+        return "Lista structurilor de date, cu scurte descrieri:"; 
       }
       else
       {
-        return "Acestea sunt clasele, structurile, uniunile i interfeele"
+        return "Lista claselor, structurilor, uniunilor i interfeelor"
 		", cu scurte descrieri:"; 
       }
 
@@ -272,7 +276,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! This is an introduction to the page with all class members. */
     virtual QCString trCompoundMembersDescription(bool extractAll)
     {
-      QCString result="Aceasta este lista tuturor ";
+      QCString result="Lista tuturor ";
       
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -316,7 +320,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! This is an introduction to the page with all file members. */
     virtual QCString trFileMembersDescription(bool extractAll)
     {
-      QCString result="Aceasta este lista tuturor ";
+      QCString result="Lista tuturor ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
         result+="funciilor, variabilelor, define-urilor, enum-urilor i typedef-urilor";
@@ -339,19 +343,19 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
 
     /*! This is an introduction to the page with the list of all header files. */
     virtual QCString trHeaderFilesDescription()
-    { return "Aceastea sunt fiierele Header care fac parte din API:"; }
+    { return "Lista fiierele Header care fac parte din API:"; }
 
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
-    { return "Aceasta este lista tuturor exemplelor:"; }
+    { return "Lista tuturor exemplelor:"; }
 
     /*! This is an introduction to the page with the list of related pages */
     virtual QCString trRelatedPagesDescription()
-    { return "Aceasta este lista tuturor documentaiilor nrudite:"; }
+    { return "Lista tuturor documentaiilor nrudite:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
     virtual QCString trModulesDescription()
-    { return "Aceasta este lista tuturor modulelor:"; }
+    { return "Lista tuturor modulelor:"; }
 
     /*! This sentences is used in the annotated class/file lists if no brief
      * description is given. 
@@ -389,7 +393,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
       }
       else
       {
-        return "Indexul Componenilor"; 
+        return "Indexul Claselor"; 
       }
 
     }
@@ -620,7 +624,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! used as an introduction to the namespace list */
     virtual QCString trNamespaceListDescription(bool extractAll)
     {
-      QCString result="Aceasta este lista tuturor ";
+      QCString result="Lista tuturor ";
       result+="namespace-urilor ";
 	  if (!extractAll) result+="documentate ";
 	  result+=", cu scurte descrieri:";
@@ -655,13 +659,13 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
 	  QCString result="Referin la ";
       switch(compType)
       {
-        case ClassDef::Class:      result+="clasa"; break;
-        case ClassDef::Struct:     result+="structura"; break;
-        case ClassDef::Union:      result+="uniunea"; break;
-        case ClassDef::Interface:  result+="interfaa"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
-        case ClassDef::Exception:  result+="excepia"; break;
+        case ClassDef::Class:      result+="clasa "; break;
+        case ClassDef::Struct:     result+="structura "; break;
+        case ClassDef::Union:      result+="uniunea "; break;
+        case ClassDef::Interface:  result+="interfaa "; break;
+        case ClassDef::Protocol:   result+="protocolul "; break;
+        case ClassDef::Category:   result+="categoria "; break;
+        case ClassDef::Exception:  result+="excepia "; break;
       }
 	  if (isTemplate) result+=" (Template) ";
 	  result+=(QCString)clName;
@@ -672,7 +676,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! used as the title of the HTML page of a file */
     virtual QCString trFileReference(const char *fileName)
     {
-      QCString result="Referin la fiierul";
+      QCString result="Referin la fiierul ";
       result+=fileName;
       return result;
     }
@@ -689,7 +693,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     virtual QCString trPublicMembers()
     { return "Metode Publice"; }
     virtual QCString trPublicSlots()
-    { return "Sloturi Publice"; }
+    { return "Conectori (slots) Publici"; }
     virtual QCString trSignals()
     { return "Semnale"; }
     virtual QCString trStaticPublicMembers()
@@ -703,7 +707,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     virtual QCString trPrivateMembers()
     { return "Metode Private"; }
     virtual QCString trPrivateSlots()
-    { return "Sloturi Private"; }
+    { return "Conectori (slots) Privai"; }
     virtual QCString trStaticPrivateMembers()
     { return "Metode Statice Private"; }
     
@@ -771,7 +775,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! This is an introduction to the page with all namespace members */
     virtual QCString trNamespaceMemberDescription(bool extractAll)
     { 
-      QCString result="Aceasta este lista tuturor membrilor ";
+      QCString result="Lista tuturor membrilor ";
       if (!extractAll) result+="documentai ";
 	  result+="din toate namespace-urile, cu legturi ctre ";
 		  
@@ -821,8 +825,8 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
         case ClassDef::Struct:     result+="structur"; break;
         case ClassDef::Union:      result+="uniune"; break;
         case ClassDef::Interface:  result+="interfa"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="protocol"; break;
+        case ClassDef::Category:   result+="categorie"; break;
         case ClassDef::Exception:  result+="excepie"; break;
       }
       result+=" a fost generat din fiier";
@@ -962,7 +966,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     }
     virtual QCString trPublicTypes()
     {
-      return "Tipuri publice";
+      return "Tipuri Publice";
     }
     virtual QCString trPublicAttribs()
     {
@@ -1017,7 +1021,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-      return "Lista lucrurilor rmase de fcut";
+      return "Lista lucrurilor de fcut";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1071,6 +1075,8 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
         "class Undocumented { };\n\n"
         "/*! Clas care este motenit n mod public */\n"
         "class PublicBase : public Truncated { };\n\n"
+        "/*! Clas template */\n"
+        "template<class T> class Templ { };\n\n"
         "/*! Clas care este motenit n mod protejat */\n"
         "class ProtectedBase { };\n\n"
         "/*! Clas care este motenit n mod privat */\n"
@@ -1081,14 +1087,15 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
         "class Inherited : public PublicBase,\n"
         "                  protected ProtectedBase,\n"
         "                  private PrivateBase,\n"
-        "                  public Undocumented\n"
+        "                  public Undocumented,\n"
+        "                  public Templ<int>\n"
         "{\n"
         "  private:\n"
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
         "Dac tagul \\c MAX_DOT_GRAPH_HEIGHT din fiierul de configuraie "
-        "Este setat la 200 acesta este graful rezultat:"
+        "este setat la 200, acesta este graful rezultat:"
         "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
         "<p>\n"
         "Csuele din partea de sus au urmtoarea semnificaie:\n"
@@ -1192,7 +1199,7 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
-      return "Acestea sunt pachetele, nsoite, acolo unde este cazul, de scurte descrieri:";
+      return "Lista pachetelor, nsoit de scurte explicaii, acolo unde acestea exist:";
     }
     /*! The link name in the Quick links header for each page */
     virtual QCString trPackages()
@@ -1217,12 +1224,12 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
-      return "Bug";
+      return "Problema (Bug)";
     }
     /*! Used as the header of the bug list */
     virtual QCString trBugList()
     {
-      return "Lista de Buguri";
+      return "Lista de Probleme (Bugs)";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1406,6 +1413,214 @@ class TranslatorRomanian: public TranslatorAdapter_1_2_16
       return "Implementat n "+trWriteList(numEntries)+".";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return "Coninut";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Lista elementelor nvechite (deprecated)";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Evenimente";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Documentaia aferent evenimentelor";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return "Tipuri n pachet";
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "Funcii n pachet";
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return "Funcii statice n pachet";
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return "Atribute n pachet";
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return "Atribute statice n pachet";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Toate";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Graful de apel al acestei funcii:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "Caut";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return "Rezultatele cutarii";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "Din pacate nu am gsit nici un document care s corespund cererii.";
+      }
+      else if (numDocuments==1)
+      {
+        return "Am gsit <b>1</b> document corespunznd cererii.";
+      }
+      else 
+      {
+        return "Am gsit <b>$num</b> documente corespunznd cererii. "
+               "Lista documentelor gsite, sortate dup relevan.";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "Gsite:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+     /*! This is used in HTML as the title of page with source code for file filename
+      */
+     virtual QCString trSourceFile(QCString& filename)
+     {
+       return " Fiierul surs " + filename;
+     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+     /*! This is used as the name of the chapter containing the directory
+      *  hierarchy.
+      */
+     virtual QCString trDirIndex()
+     { return "Ierarhia directoarelor"; }
+
+     /*! This is used as the name of the chapter containing the documentation
+      *  of the directories.
+      */
+     virtual QCString trDirDocumentation()
+     { return "Documentaia directoarelor"; }
+
+     /*! This is used as the title of the directory index and also in the
+      *  Quick links of a HTML page, to link to the directory hierarchy.
+      */
+     virtual QCString trDirectories()
+     { return "Directoare"; }
+
+     /*! This returns a sentences that introduces the directory hierarchy.
+      *  and the fact that it is sorted alphabetically per level
+      */
+     virtual QCString trDirDescription()
+     { return "Aceast ierarhie de directoare este sortat, "
+              "per nivel, in ordine alfabetic:";
+     }
+
+     /*! This returns the title of a directory page. The name of the
+      *  directory is passed via \a dirName.
+      */
+     virtual QCString trDirReference(const char *dirName)
+     { 
+       QCString  result="Director-referin "; result+=dirName; 
+       return result; 
+     }
+
+     /*! This returns the word directory with or without starting capital
+      *  (\a first_capital) and in sigular or plural form (\a singular).
+      */
+     virtual QCString trDir(bool first_capital, bool singular)
+     {
+       QCString result((first_capital ? "Directo" : "directo"));
+       if (singular) result+="r"; else result="are";
+       return result;
+     }
+
 };
 
 #endif
